From 2ae72057019e1ba2763b172760a7abe4447d5851 Mon Sep 17 00:00:00 2001
From: Hirofumi Katayama <katayama.hirofumi.mz@gmail.com>
Date: Sat, 16 Nov 2019 19:16:16 +0900
Subject: [PATCH v2] user32: Loose message box font check.

If Win10 build 1809+, then don't do message box font check.

Signed-off-by: Hirofumi Katayama <katayama.hirofumi.mz@gmail.com>
---
 dlls/user32/tests/dialog.c | 43 +++++++++++++++++++++++++++++++++++---
 1 file changed, 40 insertions(+), 3 deletions(-)

diff --git a/dlls/user32/tests/dialog.c b/dlls/user32/tests/dialog.c
index b72f08816d..3a78abfc30 100644
--- a/dlls/user32/tests/dialog.c
+++ b/dlls/user32/tests/dialog.c
@@ -1903,6 +1903,38 @@ static INT_PTR CALLBACK messageBoxFontDlgWinProc (HWND hDlg, UINT uiMsg, WPARAM
     return 0;
 }
 
+typedef void (WINAPI *FN_RtlGetVersion)(OSVERSIONINFOEXW*);
+
+static BOOL JudgeWindowsVersion(WORD major, WORD minor, WORD build)
+{
+    HINSTANCE hNTDLL;
+    FN_RtlGetVersion pRtlGetVersion;
+    OSVERSIONINFOEXW osinfo = { sizeof(osinfo) };
+
+    hNTDLL = LoadLibraryA("ntdll.dll");
+    if (!hNTDLL)
+        return FALSE;
+
+    pRtlGetVersion = (FN_RtlGetVersion)GetProcAddress(hNTDLL, "RtlGetVersion");
+    if (!pRtlGetVersion)
+        return FALSE;
+
+    (*pRtlGetVersion)(&osinfo);
+    FreeLibrary(hNTDLL);
+
+    if (osinfo.dwMajorVersion > major)
+        return TRUE;
+    if (osinfo.dwMajorVersion == major)
+    {
+        if (osinfo.dwMinorVersion > minor)
+            return TRUE;
+        if (osinfo.dwMinorVersion == minor && osinfo.dwBuildNumber >= build)
+            return TRUE;
+    }
+
+    return FALSE;
+}
+
 static void test_MessageBoxFontTest(void)
 {
     /* This dialog template defines a dialog template which got 0x7fff as its
@@ -1984,9 +2016,14 @@ static void test_MessageBoxFontTest(void)
 
     ncMetrics.cbSize = FIELD_OFFSET(NONCLIENTMETRICSW, iPaddedBorderWidth);
     SystemParametersInfoW(SPI_GETNONCLIENTMETRICS, 0, &ncMetrics, 0);
-    ok( !memcmp(&lfStaticFont, &ncMetrics.lfMessageFont, FIELD_OFFSET(LOGFONTW, lfFaceName)) &&
-        !lstrcmpW(lfStaticFont.lfFaceName, ncMetrics.lfMessageFont.lfFaceName),
-        "dialog doesn't use message box font\n");
+
+    if (!JudgeWindowsVersion(10, 0, 1809))   /* < Win10 build 1809 */
+    {
+        ok( !memcmp(&lfStaticFont, &ncMetrics.lfMessageFont, FIELD_OFFSET(LOGFONTW, lfFaceName)) &&
+            !lstrcmpW(lfStaticFont.lfFaceName, ncMetrics.lfMessageFont.lfFaceName),
+            "dialog doesn't use message box font\n");
+    }
+
     DestroyWindow(hDlg);
 }
 
-- 
2.23.0

